#
# spec file for package lollypop
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lollypop
Version:        1.0.2
Release:        1.1
Summary:        GNOME music playing application
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
Url:            https://wiki.gnome.org/Apps/Lollypop
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  meson >= 0.41
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.35.9
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
# Can't migrate to GDBus, the server-side support is not implemented yet:
#     https://bugzilla.gnome.org/show_bug.cgi?id=656330
Requires:       dbus-1-python3
Requires:       gstreamer-plugins-base
Requires:       python3-Pillow
Requires:       python3-beautifulsoup4
Requires:       python3-cairo
Requires:       python3-gobject
Requires:       python3-pylast
Recommends:     easytag
Recommends:     kid3-cli
Recommends:     python3-wikipedia
Recommends:     youtube-dl
Suggests:       python3-textblob
BuildArch:      noarch

%description
Lollypop is a GNOME music playing application. It provides the following
features:
* Supports mp3/4, ogg and flac
* Genre/Cover browsing
* Genre/Artist/Cover browsing
* Search
* Main playlist (called queue in other apps)
* Party mode
* Replay gain
* Cover art downloader
* Context artist view
* MTP sync
* Fullscreen view
* Radios support
* Last.fm support
* Auto install codecs
* HiDPI support
* Tunein support.

%package -n gnome-shell-search-provider-lollypop
Summary:        GNOME music playing application - gnome-shell search provider
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    packageand(%{name}:gnome-shell)

%description -n gnome-shell-search-provider-lollypop
Lollypop is a GNOME music playing application.

This package contains a search provider to enable GNOME Shell to get
search results from %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%doc AUTHORS README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%exclude %{_libexecdir}/lollypop-sp
%{_datadir}/%{name}
%{_datadir}/metainfo/org.gnome.Lollypop.appdata.xml
%{_datadir}/applications/org.gnome.Lollypop.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Lollypop.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Lollypop*
%{python3_sitelib}/lollypop/

%files -n gnome-shell-search-provider-%{name}
%{_libexecdir}/lollypop-sp
%{_datadir}/dbus-1/services/org.gnome.Lollypop.SearchProvider.service
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Lollypop.SearchProvider.ini

%files lang -f %{name}.lang

%changelog
* Fri Mar 22 2019 antoine.belvire@opensuse.org
- Update to version 1.0.2:
  * Fix a crossfading issue.
- Changes from version 1.0.1:
  * Force connect when network is available
    (glgo#World/lollypop#1588).
  * Fix a crash on empty collection (glgo#World/lollypop#1712).
  * Do not empty collection if disk is removed.
  * Fix search provider.
* Mon Mar 18 2019 antoine.belvire@opensuse.org
- Update to version 1.0:
  * Spotify/YouTube support is back.
  * New application menu.
  * Many bug fixes.
- Add youtube-dl as recommended dependency.
* Thu Mar 14 2019 antoine.belvire@opensuse.org
- Update to version 0.9.925:
  * Fix a crash in device manager (glgo#World/lollypop#1698).
* Sun Mar  3 2019 antoine.belvire@opensuse.org
- Update to version 0.9.924:
  * Fix an issue with compilations.
* Wed Feb 27 2019 antoine.belvire@opensuse.org
- Update to version 0.9.923:
  * Fix a crash when adding a track to a playlist
    (glgo#World/lollypop#1684).
  * Update icons using colors of the GNOME palette.
  * Replace Ctrl+s with Ctrl+, for accessing settings
    (glgo#World/lollypop#1623).
* Mon Feb 25 2019 antoine.belvire@opensuse.org
- Update to version 0.9.922:
  * Enhanced adaptive mode.
  * Reworked similar artists popover.
  * Bug fixes.
* Wed Feb 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- python3-Pillow is required rather than recommended since
  version 0.9.920.
* Tue Feb 19 2019 antoine.belvire@opensuse.org
- Update to version 0.9.921:
  * Fix an issue with HiDPI.
  * Fix an issue with special chars.
  * Allow year navigation from album.
- Changes from version 0.9.920:
  * Add an equalizer.
  * New album view.
  * New default sidebar.
* Tue Jan 29 2019 antoine.belvire@opensuse.org
- Update to version 0.9.916:
  * Fix inotify code.
  * Faster collection scanner.
* Sat Jan 26 2019 antoine.belvire@opensuse.org
- Update to version 0.9.915:
  * Fix an issue with artist playback (glgo#World/lollypop#1611).
  * Fix an issue with lyrics (glgo#World/lollypop#1606).
  * Fix an issue in collection scanner.
  * Fix an issue with collection history.
* Wed Jan 23 2019 antoine.belvire@opensuse.org
- Update to version 0.9.914:
  * Fix a crash in radios (glgo#World/lollypop#1606).
- Changes from version 0.9.913:
  * Fix issues in collection scanner.
  * Enhance mini-player (glgo#World/lollypop#1607).
* Fri Jan 18 2019 antoine.belvire@opensuse.org
- Update to version 0.9.912:
  * Fix an issue with playlists (glgo#World/lollypop#1599).
  * Add an error message for conversion failure when music is on
    smb share (glgo#World/lollypop#1585).
  * Increase size of album cover exported for MPRIS
    (glgo#World/lollypop#1593).
* Wed Jan 16 2019 antoine.belvire@opensuse.org
- Update to version 0.9.911:
  * Fix search provider issue (glgo#World/lollypop#1493).
  * Escape playlists on sync (glgo#World/lollypop#1597).
  * Scrobble on connect if a track is playing
    (glgo#World/lollypop#1588).
  * Fix a crash when object name is empty
    (glgo#World/lollypop#1596).
  * Fix radio restore state (glgo#World/lollypop#1595).
  * Fix scroll volume down when window is not focused
    (glgo#World/lollypop#1591).
* Tue Jan  8 2019 antoine.belvire@opensuse.org
- Update to version 0.9.910:
  * Fix a small issue with adaptive mode.
* Thu Jan  3 2019 antoine.belvire@opensuse.org
- Update to version 0.9.909:
  * Enhanced drag and drop.
  * Bug fixes (glgo#World/lollypop#1576, glgo#World/lollypop#1583).
* Thu Dec 27 2018 antoine.belvire@opensuse.org
- Update to version 0.9.908:
  * Fix an issue with artist view.
  * Various bug fixes (glgo#World/lollypop#1576,
    glgo#World/lollypop#1577, glgo#World/lollypop#1579,
    glgo#World/lollypop#1580).
* Sat Dec 22 2018 antoine.belvire@opensuse.org
- Update to version 0.9.907:
  * Fix some playback issues (glgo#World/lollypop#1574).
  * Import loved tracks from playlists (glgo#World/lollypop#1573).
  * Fix a crash (glgo#World/lollypop#1571).
* Wed Dec 19 2018 antoine.belvire@opensuse.org
- Update to version 0.9.906:
  * Fix bug where cover was never shown.
- Changes from version 0.9.905:
  * Bugfixes.
* Tue Dec 18 2018 antoine.belvire@opensuse.org
- Update to version 0.9.904:
  * Fix a crash in information popover (glgo#World/lollypop#1564).
  * Fix a crash upon new album image selection
    (glgo#World/lollypop#1568).
  * Make right-click on album more consistent
    (glgo#World/lollypop#1566).
  * Don't show an empty similar artists popover when there is no
    similar artist (glgo#World/lollypop#1565).
* Sat Dec 15 2018 antoine.belvire@opensuse.org
- Update to version 0.9.903:
  * Fix an issue with lyrics translation
    (glgo#World/lollypop#1563).
- Changes from version 0.9.902:
  * Fix empty popover display after clicking "Show Lyrics"
    (glgo#World/lollypop#1561).
  * Clarify error message in lyrics view when module textblob is
    not installed.
- Add python-textblob as suggested dependency:
  * It allows lollypop to translate lyrics in user language. Not a
    new feature, it was actually introduced in 0.9.522.
  * Note that module textblob is not available in Factory yet.
* Fri Dec 14 2018 antoine.belvire@opensuse.org
- Update to version 0.9.901:
  * Fix a crash in information popover (glgo#World/lollypop#1560).
- Changes from version 0.9.900:
  * New navigation mode when sidebar is off.
  * New smart playlists (glgo#World/lollypop#890).
  * Faster album loading.
  * Faster track loading.
  * Better sync to device.
  * Restore playback position on start.
  * Better adaptive mode: radio support, toolbar buttons, search…
  * Various bugfixes.
* Thu Nov  8 2018 antoine.belvire@opensuse.org
- Update to version 0.9.612:
  * Fix an issue with lyrics (glgo#World/lollypop#1536).
  * Fix an issue with kid3-cli (glgo#World/lollypop#1527).
* Sun Nov  4 2018 antoine.belvire@opensuse.org
- Update to version 0.9.611:
  * Fix an issue with track management.
* Sun Oct 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.610:
  * Fix broken MTP sync on GNOME 3.30 (glgo#World/lollypop#1522).
  * Fix a crash about album discs (glgo#World/lollypop#1511).
  * Fix broken radio view (glgo#World/lollypop#1529).
- Remove useless runtime dependency on gobject-introspection.
* Thu Oct 25 2018 antoine.belvire@opensuse.org
- Update to version 0.9.609:
  * Fix a "sqlite db locked" introduced in 0.9.608.
- Changes from version 0.9.608:
  * Fix an issue with multiple disc albums
    (glgo#World/lollypop#1528).
  * Fix hang while updating collection (glgo#World/lollypop#1517).
  * Stop playback if writing to tags on current album
    (glgo#World/lollypop#1527).
* Mon Oct 22 2018 antoine.belvire@opensuse.org
- Update to version 0.9.607:
  * Fix playlists creation.
  * Update translations.
- Change from version 0.9.606:
  * Fix a crash in radios.
* Fri Oct 19 2018 antoine.belvire@opensuse.org
- Update to version 0.9.605:
  * Sort albums with full date (glgo#World/lollypop#1301).
  * Faster album loading.
  * Add a button to go from search to artist.
  * Better Wikipedia search.
  * Allow importing loved tracks (glgo#World/lollypop#1441).
  * Enable/disable last.fm scrobbling from main window
    (glgo#World/lollypop#1509).
  * Fix some crashes (glgo#World/lollypop#1520,
    glgo#World/lollypop#1517)
  * Handle PART= comment in tags (glgo#World/lollypop#1515).
  * Fix music stop after first enqueued song
    (glgo#World/lollypop#1514).
  * Fix genre and artist column widths (glgo#World/lollypop#1513).
  * Reworked application icon.
- Updated path to icons in file list: New svg icon added.
* Mon Oct  8 2018 antoine.belvire@opensuse.org
- Update to version 0.9.604:
  * Fix genres in decade view.
- Changes from version 0.9.603:
  * Fix a crash in artist view.
* Sat Oct  6 2018 antoine.belvire@opensuse.org
- Update to version 0.9.602:
  * Fix a freeze in playlists (glgo#World/lollypop#1507).
  * Make build reproducible (glgo#World/lollypop#1502,
    boo#1110032).
  * Use Gio.Drive.is_removable() (glgo#World/lollypop#1498).
  * Updated translations.
- Drop lollypop-0.9.601-reproducible.patch: Fixed upstream.
* Thu Sep 27 2018 antoine.belvire@opensuse.org
- Add lollypop-0.9.601-reproducible.patch: Make build reproducible
  (boo#1110032).
* Mon Sep 24 2018 antoine.belvire@opensuse.org
- Update to version 0.9.601:
  * Fix stupid crash (glgo#World/lollypop#1501).
- Drop lollypop-0.9.600-fix-crash-lyrics-view.patch: Fixed
  upstream.
* Fri Sep 21 2018 antoine.belvire@opensuse.org
- Update to version 0.9.600:
  * Reworked playlist management.
  * Reworked sync to MTP.
  * lollypop-portal is not needed anymore.
  * Updated translations.
  * Bugfixes:
    + glgo#World/lollypop#1495
    + glgo#World/lollypop#1494
    + glgo#World/lollypop#1484
    + glgo#World/lollypop#1457
- Add lollypop-0.9.600-fix-crash-lyrics-view.patch: Fix crash
  upon lyrics view closing, picked from upstream
  (glgo#World/lollypop#1501).
- Fix typo in recommended package name: python3-Pillow.
- No longer recommend lollypop-portal.
* Thu Aug 23 2018 antoine.belvire@opensuse.org
- Update to version 0.9.522:
  * Browse albums by years.
  * Bug fixes.
* Sat Jul 21 2018 antoine.belvire@opensuse.org
- Update to version 0.9.521:
  * Fix an issue in party mode.
* Mon Jul 16 2018 antoine.belvire@opensuse.org
- Update to version 0.9.520:
  * Set menu initial state. Fix glgo#World/lollypop#1467.
  * Same fix for playback action.
* Mon Jul  9 2018 antoine.belvire@opensuse.org
- Update to version 0.9.519:
  * Fix crash in TuneIn. Fix gl#World/lollypop#1465.
  * Set default value to both. Fix gl#World/lollypop#1463.
  * Show lyrics for current popover track.
  * Make lyrics view more discoverable. Fix gl#World/lollypop#1451.
  * Only show one artist in InfoPopover.
  * Hide Next Popover when showing main menu.
- Actually provide a -lang subpackage.
* Sun Jul  1 2018 antoine.belvire@opensuse.org
- Update to version 0.9.518:
  * Restore next popover.
- Update to version 0.9.517:
  * Bug fixes.
  * Remove party mode button.
  * Disable appmenu.
* Mon Jun 25 2018 antoine.belvire@opensuse.org
- Update to version 0.9.516:
  * Fix screenshot height
  * Fix lyrics reader (from tags). Fix #1450
  * Fix Alt+a shortcut  behaviour
  * Allow users to discover sidebar options
  * Some sensitivity tweaking
* Tue Jun 19 2018 antoine.belvire@opensuse.org
- Update to version 0.9.515:
  * Fix Missing artists list. Fix #1443
  * Crash when opening the playlist popup if the random playlist is
    selected. Fix #1447
  * Properly calculate height for every case. Fix #1445
  * Save currently playing/queue as new playlist. Fix #1439
  * Fix #1440
  * Fix a crash when an album is missing an URI
  * Fix typo
  * Add ⮟ to fastscroll widget
  * Gtk.FileChooserDialog only blocks key-press-event. Fix #1435
  * Disable scroll event on combobox. #1435
  * Add ⮝ to fastscroll widget. Fix #1434
- Update git URL.
* Thu May 24 2018 antoine.belvire@opensuse.org
- Update to version 0.9.514:
  * Fix search shortcut.
- Update to version 0.9.513:
  * Workaround a crash in Pango.
  * Enable new encoders in MTP sync.
  * Use Gtk.Gesture.
* Thu May 17 2018 antoine.belvire@opensuse.org
- Update to version 0.9.512:
  * Fix a small issue with artist CellRender.
- Update to version 0.9.511:
  * Fix a bug showing unwanted empty widget.
- Update to version 0.9.510:
  * Fix inotify support.
- Update to version 0.9.509:
  * Fix fullscreen on multihead.
  * Rework sidebar.
* Thu May  3 2018 badshah400@gmail.com
- Update to version 0.9.508:
  * Do not empty ids. Fix glgo#gnumdk/lollypop#1414
  * Add <Alt>a shortcut to show current track artist. Fix
    glgo#gnumdk/lollypop#1413
  * Add Alt-a shortcut
  * Donation popup (beer, beer, beer)
  * Simpler radio widget
  * Handle external tracks as internal
  * Updated translations
- Add Recommends: python3-pillow: optional dependency.
* Sat Apr 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.507:
  * Fix crash. Fix #1405.
  * Spelling: Unplayed x2, USB.
  * Update translations.
  * Allow user to enable USB disk from UI. Fix #1403.
* Thu Apr 19 2018 antoine.belvire@opensuse.org
- Update to version 0.9.506:
  * Create information store on init. Fix #1402.
- Update to version 0.9.505:
  * Rework all Shuffle code.
  * Add some blur to lyrics view.
  * Import playlists from disk.
  * Allow exporting playlists to disk.
  * Bug fixes.
* Sat Apr 14 2018 antoine.belvire@opensuse.org
- Update to version 0.9.504:
  * Fix indicator in playlists.
  * Update translations
- Update to version 0.9.503:
  * Fix Enable network access ignored by lyrics and information
    popover.
- Update to version 0.9.502:
  * Fix a crash.
- Update to version 0.9.501:
  * Bug fixes.
- Update to 0.9.500:
  * Rework information popover.
  * New lyrics widget.
- Use %%license instead of %%doc for license file (boo#1082318).
- Add %%check section.
- Clean dependencies:
  * Add python3-beautifulsoup4 as runtime dependency (needed by
    new lyrics widget as well as existing artwork search
    feature).
  * Remove useless explicit dependencies:
    + gettext-runtime: Already required by intltool.
    + libxml2: Already required by itstool.
    + ninja: Already required by meson.
    + gstreamer: Already required by gstreamer-plugins-base.
    + pkgconfig(gio-2.0): Already required by pkgconfig(gtk+-3.0).
  * Remove fdupes (no duplicated files).
  * Remove unneeded hicolor-icon-theme.
  * Remove unneeded pkgconfig(gsettings-desktop-schemas).
  * Remove git-core (useless without internet access during
    build).
  * Add desktop-files-utils as build dependency (used in %%check
    section), remove it from runtime requirements.
* Wed Mar 28 2018 antoine.belvire@opensuse.org
- Update to version 0.9.403:
  * Workaround bgo#766284.
  * Show notifications when window is not visible.
  * Close notification on quit.
  * Fix a crash when trying to love a None track id.
- Update to version 0.9.402:
  * Quit app on SIGTERM/SIGINT.
  * Bugfixes.
- Update to version 0.9.401:
  * Fix an issue in Collection scanner.
  * Add an option to disable compilations.
* Fri Mar  9 2018 badshah400@gmail.com
- Update to version 0.9.400:
  * Fix meson build
  * Rework generate_data.sh
  * Updated translations
* Wed Dec 27 2017 antoine.belvire@opensuse.org
- Update to version 0.9.306:
  * Fix crash due to broken commit.
  * Add support for audio/x-wavpack.
  * Update GTK minimal version to 3.20.
  * Update translations.
- Changes from version 0.9.305:
  * Allow jumping to artist from search view.
  * Rework fullscreen layout.
  * Choose startup view.
- Update spec file:
  * Change URL and Source fields: Lollypop has moved to GNOME's
    infrastructure.
  * Drop post(un) scriptlets: They are empty for Tumbleweed and
    Leap 15 and this package does not build anymore with previous
    versions of openSUSE.
  * Drop glib2_gsettings_schema_requires (was needed for post(un)
    macros).
  * Drop conditionals for openSUSE Leap 42.3 and older.
  * Ran spec-cleaner.
- Add _service file.
* Mon Oct 16 2017 badshah400@gmail.com
- Update to version 0.9.303:
  + Make lollypop-cli working again
  + Do not remove tracks if collection does not exist
- Drop lollypop-libexecdir-location.patch, fixed upstream.
* Sun Oct  8 2017 jengelh@inai.de
- Trim description.
* Sat Oct  7 2017 kkirill@opensuse.org
- Update to version 0.9.303:
  + Another bug fix: sync code was broken
- Changes from version 0.9.302:
  + Fix important issue with flatpak package
  + Fix radios
* Wed Oct  4 2017 badshah400@gmail.com
- Update to version 0.9.300:
  + New "never played albums" section.
  + Remove all youtube-dl play code.
  + Bug fixes.
- Rebase lollypop-libexecdir-location.patch.
* Tue Jul 11 2017 badshah400@gmail.com
- Update to version 0.9.244:
  + Fix build issues which caused binary files to have
    non-executable permissions.
  + Drop rhythmbox2lollypop binary, and adapt its features into
    lollypop-cli.
- Update file list in keeping with rhythmbox2lollypop removal.
- No longer need to manually set exec perms on binaries, this is
  taken care of by the installer now.
- Update BuildRequires:
  + Explicitly require meson >= 0.40.0, as that is the least
    supported version now.
  + Explicitly require gettext-runtime >= 0.19.7 as building now
    requires `msgfmt --xml` which is only supported from this
    version (NB: gettext-runtime was being automatically pulled
    in earlier).
* Thu Jul  6 2017 badshah400@gmail.com
- Update to version 0.9.243:
  + Meson build
  + Fix a GTK require issue.
- Add lollypop-libexecdir-location.patch: Pick up libexecdir from
  option passed to meson instead of harcoding $prefix/libexecdir
  (we don't even use /usr/libexecdir).
* Mon Jul  3 2017 badshah400@gmail.com
- Update to version 0.9.241:
  + Fix an important issue with Spotify API
* Fri Jun 16 2017 badshah400@gmail.com
- Update to version 0.9.240:
  + Fix an issue with progressbar position on state restoration.
* Sat Jun  3 2017 badshah400@gmail.com
- Update to version 0.9.239:
  + Bug fixes, including for boo#1040253.
* Fri May 12 2017 badshah400@gmail.com
- Update to version 0.9.233:
  + Fix an important crash.
- Changes from version 0.9.232:
  + Bug fixes.
* Thu Apr 13 2017 badshah400@gmail.com
- Update to version 0.9.231:
  + Respect gtk dark theme setting.
  + Rework session management.
  + Enhanced mime type detection.
  + Allow lyrics for radios.
- Add Recommends on easytag: used when one clicks on the "edit
  tags" button in lollypop (boo#1033858).
- lollypop-sp moved to %%{_libexecdir}, adapt file-list
  appropriately.
* Fri Mar 24 2017 badshah400@gmail.com
- Update to version 0.9.230:
  + Bug fixes.
  + Enhanced charts support.
- Update file list for main package.
* Fri Feb  3 2017 badshah400@gmail.com
- Update to version 0.9.229:
  + Do not show charts in collection (Disable/Enable charts to
    fix it).
- Changes from version 0.9.228:
  + Fix an issue with MPRIS.
  + Do not list web artists in sync dialog.
  + Order tracks by name if no track number available.
- Add Recommends on lollypop-portal (now in factory) and
  kid3-cli (used to save tag changes to audio files).
* Tue Jan 17 2017 badshah400@gmail.com
- Update to version 0.9.227:
  + Fix an issue with Itunes charts.
  + Fix an issue with MPRIS.
  + Fix an issue with fast scrolling.
- Changes from version 0.9.226:
  + Do not use Gio for http downloads!
- Changes from version 0.9.225:
  + Bug fixes.
  + Show artists in sync view.
* Sat Jan  7 2017 badshah400@gmail.com
- Update to version 0.9.224:
  + Allow user to manually rate songs/albums.
  + Low quality image search fallback support when no Google API
    key available.
  + Playback fixes.
  + New fast scroll widget!
  + New loved album section.
  + Original date tag support.
  + FIX AN IMPORTANT MEMORY LEAK (on first collection scan).
  + Enhanced lyrics support.
  + Enhanced search widget.
  + Itunes search provider.
- Update file lists and %%suse_update_desktop_file usage to change
  in .desktop, icons and appdata file names.
* Thu Dec 15 2016 badshah400@gmail.com
- Update to version 0.9.223:
  + Bypass gvfs-http (bgo#775600).
  + Better search provider.
  + Now (opt) depends on lollypop-portal (not release yet, and so
    not in openSUSE so far):
    https://github.com/gnumdk/lollypop-portal.
- Changes from version 0.9.222:
  + Enhanced popularity behaviour.
  + Fix crash in playlist manager.
* Mon Nov 28 2016 badshah400@gmail.com
- Update to version 0.9.221:
  + Fix a crash with radio playback.
  + Small enhancements.
- Changes from version 0.9.220:
  + Fix crash in settings.
  + Fix crash in artwork dialog.
- Changes from version 0.9.219:
  + Fix an issue with some MTP devices.
  + Fix an issue with favorite tag editor.
  + Fix an issue with loved playlist.
* Wed Nov 23 2016 badshah400@gmail.com
- Update to version 0.9.218:
  + Fix an issue with search provider.
  + Simpler playback menu.
- Exclude from amain package and package the search provider
  utility -- %%{_datadir}/%%{name}/lollypop-sp -- as part of the
  gnome-shell-search-provider-lollypop, with exec attributes.
* Sun Nov 20 2016 badshah400@gmail.com
- Update to version 0.9.217:
  + Lollypop search provider.
  + Netease support for web playback.
  + Bug fixes.
- Split out a new package: gnome-shell-search-provider-lollypop
  to provide the search provider for gnome-shell.
- Add Group tags for all packages.
* Sun Nov 20 2016 badshah400@gmail.com
- Update to version 0.9.216:
  + Fix issue with radios.
- Changes from version 0.9.215:
  + New filtering feature.
  + Force GDK X11 backend (gh#gnumdk/lollypop#810).
  + Bugfixes.
* Thu Nov 10 2016 badshah400@gmail.com
- Update to version 0.9.214:
  + Allow using network share as collection.
  + Allow disabling charts.
  + Allow disabling network access.
* Sat Oct 15 2016 badshah400@gmail.com
- Update to version 0.9.211:
  + Fix an issue on Ubuntu 16.10.
  + Fix an issue with volume control.
- Changes from versions 0.9.207 through 0.9.210:
  + See release history at
    https://github.com/gnumdk/lollypop/releases.
- Bump up minimum required gtk3 version to 3.14 in keeping with
  config.ac file.
* Thu Sep 29 2016 badshah400@gmail.com
- Update to version 0.9.206:
  + Fix an issue with GTK 3.22.
  + Do not search in youtube based on audio length.
  + Add lollypop-cli command line helper.
* Fri Sep 23 2016 badshah400@gmail.com
- Update to version 0.9.205:
  + Youtube support.
  + MPRIS fixes.
  + Read lyrics from tags.
  + See https://github.com/gnumdk/lollypop/releases for full list
    of changes.
* Sun Sep  4 2016 mailaender@opensuse.org
- Update to version 0.9.113:
  + Enhanced search engine
  + MTP sync for albums
  + Move stats to settings dialog
  + Move artist artwork outside cache
  + Fix Lastfm scrobbler
  + Guess tracknumber from filename
  + Fix issues with Unity
  + Rework all code (may have introduced unwanted regressions)
* Fri Jul 15 2016 badshah400@gmail.com
- Update to version 0.9.112:
  + Fix an issue with image downloader:
    https://duckduckgo.com/i.js is not available anymore,
    duckduckgo API is limited to instant search... Switch to
    Google Custom Search (API key needed).
- Changes from versions 0.9.108 through 0.9.111:
  + See https://github.com/gnumdk/lollypop/releases.
* Sun Jun  5 2016 badshah400@gmail.com
- Update to version 0.9.107:
  + Bug fixes release.
- Changes from versions 0.9.106:
  + Option to store covers in tags (needs kid3).
  + Fix an issue in Fullscreen.
  + Other bug fixes.
- Changes from version 0.9.105:
  + Fix an issue with sortorder.
  + Fix an issue with HiDPI in MPRIS.
  + Fix issues with artwork cache.
  + Add support for shortcuts window.
* Sun May  8 2016 badshah400@gmail.com
- Update to version 0.9.104:
  + Fix an issue with read only fs
  + Add support for disc subtitle comment
  + Fix an issue with overlay
  + Remove arrow in list (bad with artist artwork, bad on
    elementary, ...)
- Changes from version 0.9.100 through 0.9.103:
  + See release history:
    https://github.com/gnumdk/lollypop/releases.
* Thu Apr 28 2016 badshah400@gmail.com
- Update to version 0.9.99:
  + Add support for artist artwork
  + Boost performance (one more time)
  + Bugfixes in collection scanner
  + Tunein search
- Add Recommends on python3-wikipedia for openSUSE > 1320,;
  enables the optional wikipedia feature (python3-wikipedia
  recently introduced into Factory). N.A. for openSUSE <= 13.2 or
  Leap 42.1.
* Wed Apr 27 2016 badshah400@gmail.com
- Update to version 0.9.98:
  + Last.fm was not working for users without Gnome Online
    Account.
  + Various bug fixes.
- Changes from version 0.9.97:
  + Fix an issue in MTP sync.
  + Fix an issue when showing artists for track.
- Changes from version 0.9.96:
  + Various bug fixes.
* Tue Apr 12 2016 badshah400@gmail.com
- Update to version 0.9.95:
  + Various bug fixes.
  + Enable Gnome Shell 3.20 MPRIS controls.
  + Move to GIO DBus on GNOME 3.20 (Thanks to Gnome Music code).
  + Should work again on Elementary OS.
- Delete unnecessary python cache files to avoid a ton of rpmlint
  warnings.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.94:
  + Fix an issue with HiDPI.
* Wed Apr  6 2016 badshah400@gmail.com
- Update to version 0.9.93:
  + Fix an issue with overlays.
- Changes from version 0.9.92:
  + Allow multiple artists per album.
  + Faster album loading.
  + New Popover for context view.
  + Fixes for GNOME 3.20.
  + Remove Wikia support (broken) .
* Thu Mar 24 2016 badshah400@gmail.com
- Update to version 0.9.91:
  + Bug fixes.
- Changes from version 0.9.90:
  + Rewritten queue popover.
  + New playlists/albums popover (You can manage tracks/albums
    while browsing your collection).
  + New overlay buttons.
  + Drag & drop in playlists.
  + Fast queuing.
  + Multi playlists selection.
  + Jump to current track button.
  + Elementary OS support back.
* Wed Feb 17 2016 badshah400@gmail.com
- Update to version 0.9.86:
  + Fix an issue with crossfading.
  + Finally support artwork in notifications.
  + Add a new "responsive design" mode (Ctrl + m for Mini player).
  + Somes fixes in MTP sync.
- Changes from versions 0.9.83 through 0.9.85:
  + See upstream documentation of changes at
    https://github.com/gnumdk/lollypop/releases.
* Wed Feb  3 2016 badshah400@gmail.com
- Update to version 0.9.82:
  + Fix an important issue in collection scanner.
  + Fix an issue with progress bar.
- Changes from version 0.9.81:
  + Fix an issue in MTP code.
  + Update translations.
  + Rework settings dialog.
- Changes from version 0.9.80:
  + Crossfading support.
  + Allows user to merge views by selecting multiple items.
  + Converts files to MP3 on MTP sync (Android Phones, ...).
  + Fix an issue with headerbar.
* Thu Dec 24 2015 badshah400@gmail.com
- Update to version 0.9.75:
  + Use Duckduckgo, Google API is dead.
  +`Add a slider to select covers size.
* Sat Dec  5 2015 badshah400@gmail.com
- Update to version 0.9.74:
  + Fix issue in scanner.
- Changes from version 0.9.72:
  + Handle artist sort order tag.
  + Fix search dialog.
  + Allow popover in search dialog (Gtk 3.18).
- Changes from version 0.9.71:
  + Fix issue in fullscreen.
* Sat Nov 28 2015 badshah400@gmail.com
- Update to version 0.9.70:
  + Initial MPD support (unstable).
  + Animation when loading radios.
  + Stats in about dialog.
  + Restore window position when hidden.
  + Right click on albums.
  + Fix MTP errors.
* Fri Nov 13 2015 badshah400@gmail.com
- Initial package.
